pub fn native_histogram_field_type(name: &str) -> Option<ConcreteDataType>Expand description
Returns the exact Greptime type for a persisted native histogram field.
pub fn native_histogram_field_type(name: &str) -> Option<ConcreteDataType>Returns the exact Greptime type for a persisted native histogram field.