pub fn native_histogram_value_type() -> &'static ConcreteDataTypeExpand description
Returns the exact Greptime type for a complete native histogram value.
pub fn native_histogram_value_type() -> &'static ConcreteDataTypeReturns the exact Greptime type for a complete native histogram value.